
```eval_rst
.. automodule:: multicontentsmanager
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: multicontentsmanager.extension
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: multicontentsmanager.handlers
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: multicontentsmanager.metacontentsmanager
   :members:
   :undoc-members:
   :show-inheritance:


```